@@ -349,7 +349,7 @@ impl GitAuthenticator {
 
 		let candidates = [
 			"id_rsa",
-			"id_ecdsa,",
+			"id_ecdsa",
 			"id_ecdsa_sk",
 			"id_ed25519",
 			"id_ed25519_sk",
@@ -615,6 +615,9 @@ impl PrivateKeyFile {
 					None
 				},
 				Ok(key_info) => {
+					if key_info.format == ssh_key::KeyFormat::Unknown {
+						warn!("Unknown key format for key: {}", self.private_key.display());
+					}
 					if key_info.encrypted {
 						prompter.prompt_ssh_key_passphrase(&self.private_key, git_config)
 					} else {
